<?php

/**
 * @file
 *  Contains Cookie tracking method
 */

/**
 * Increments a user's view count by arbitrary figure
 *
 * @param int $nid
 *  Node ID of current node
 * @param int $add
 *  figure to add to the existing count
 * @return int $count
 *  Number of views after new addition
 */
function limited_views_add($nid, $add = 1) {
  static $progressive;
  if (is_null($progressive)) {
    $progressive = limited_views_get_view_count();
  }
  // Don't count custom 404 pages which may get triggered when the page can't find a static resource
  if ($custom = variable_get('site_404')) {
    $path = explode('/', drupal_get_normal_path($custom));
    if ($path[1] == $nid) {
      return $progressive; // Don't set the cookie
    }
  }
  $progressive += $add;
  $cookie_timestamp = 'limited_views_count['. $nid .'][timestamp]';
  setcookie($cookie_timestamp, time(), time() + LIMITED_VIEWS_EXPIRY_TIME, '/');
  $cookie_count = 'limited_views_count['. $nid .'][count]';
  setcookie($cookie_count, $add, time() + LIMITED_VIEWS_EXPIRY_TIME, '/');
  return $progressive;
}

/**
 * Adds the javascript to the page.
 * 
 * @param integer $nid Node ID
 */
function limited_views_add_js($nid) {
  // Add some basic parameters
  drupal_add_js(array('limited_views' => array(
    'nid' => $nid,
    'expiry' => LIMITED_VIEWS_EXPIRY_TIME,
    'threshold' => LIMITED_VIEWS_VIEW_THRESHOLD,
  )), 'setting');
  drupal_add_js(drupal_get_path('module', 'limited_views') . '/inc/jquery.cookie.js', 'module');
  drupal_add_js(drupal_get_path('module', 'limited_views') . '/inc/json2.js', 'module');
  drupal_add_js(drupal_get_path('module', 'limited_views') . '/inc/limited_views.cookie.js', 'module');
}

/**
 * Returns the number of views a user has accrued on their cookie
 *
 * This should always be used to access the view count, as it sanitizes the user
 * provided data.
 *
 * To use this in a test, you will have to use === in your statement to force
 * type checking.
 *
 * @return int
 *  number of content views
 */
function limited_views_get_view_count() {
  $expiry_timestamp = time() - LIMITED_VIEWS_EXPIRY_TIME;
  $view_count = 0;
  arg(0) == 'node' ? $current_nid = arg(1) : $current_nid = NULL;
  $cookie = json_decode($_COOKIE['limited_views_count']);
  $count_data = (is_array($cookie)) ? $cookie : array();
  foreach($count_data as $data) {
    if ($data->nid != $current_nid && $data->timestamp > $expiry_timestamp) { // this reduces the node count so the current page isn't considered.
      $view_count ++;
    }
  }
  return $view_count;
}

/**
 * Tests if the user has cookies enabled and has a limited_views cookie
 *
 * Beware, this causes a full page refresh if the user doesn't have the cookie yet
 */
function limited_views_check_method() {
  if (is_array($_COOKIE['limited_views_count'])) {
    // user already has a count cookie
    return TRUE;
  }
  else {
    $cookies_enabled = (bool)$_COOKIE['limited_views_cookie_enabled'];
    if (empty($cookies_enabled) && !$_GET['cookie_check']) {
      // set a test cookie if the cookie doesnt exist, and the test isn't already running
      setcookie('limited_views_cookie_enabled', 1, 0, '/');
      $query = array('cookie_check' => 1);
      $url = explode('?', trim($_SERVER['REQUEST_URI'], '/'));
      $other_queries = explode('&', $url[1]);
      foreach ($other_queries as $string) {
        $parts = explode('=', $string);
        $query[$parts[0]] = $parts[1];
      }
      drupal_goto($url[0], $query);
    }
    if (empty($cookies_enabled) && $_GET['cookie_check']) {
      // the test is running and the cookie doesn't exist, user is not
      // accepting our cookie
      return FALSE;
    }
    if ($cookies_enabled) {
      // client is accepting our cookie
      return TRUE;
    }
  }
}
