/**
 * Limited Views javascript settings and checking methods
 */

Drupal.behaviors.limited_views = function(context) {
  var threshold = Drupal.settings.limited_views.threshold;
  var expiry = Drupal.settings.limited_views.expiry; // seconds to days
  var expirydays = expiry / 60 / 60 / 24; // seconds to days
  var count = limited_views_get_view_count();
  if (count <= threshold) {
    limited_views_add();
  }
  if (count >= threshold - 1) { // second from last allowed view
    if (!$.cookie('NO_CACHE')) {
      var d = new Date();
      d.setMinutes(d.getMinutes() + 2);
      $.cookie('NO_CACHE', 'Y', { expires: d, path: '/' }); // Set the NO_CACHE cookie so that the next page load uses the PHP function to check.
    }
  }
  
  /**
   * Adds cookies to track number of node views
   */
  function limited_views_add() {
    var nodeobj = new Array();
    var nid = Drupal.settings.limited_views.nid;
    var timestamp = Math.floor(new Date().getTime()/1000);
    if ($.cookie('limited_views_count')) {
      var cookie = JSON.parse($.cookie('limited_views_count'));
    }
    var newnid = true;
    // check if this node is a new one
    if (cookie) {
      nodeobj = cookie;
      $.each(nodeobj, function(index, value) {
        if (value['nid'] == nid) {
          newnid = false;
        }
      });
    }
    if (newnid == true) { // we have a new nid so set a cookie
      var newobj = {
        nid: nid,
        timestamp: timestamp
      };
      var result = nodeobj.concat(newobj);
      var jsonstring = JSON.stringify(result, null, 2); // convert the object to a json string
      $.cookie('limited_views_count', jsonstring, { expires: expirydays, path: '/' }); // store the json object in the cookie
    }
  }
  
  function limited_views_get_view_count() {
    var expiry_stamp = Math.floor(new Date().getTime()/1000) - expiry;
    var count = 0;
    if ($.cookie('limited_views_count')) {
      var nodeobj = JSON.parse($.cookie('limited_views_count')); // cookie containing object
      if (nodeobj != null) {
        $.each(nodeobj, function(index, value) {
          if (value['timestamp'] > expiry_stamp) {
            count ++;
          }
        });
      }
    }
    return count;
  } 
};